@@ -35,7 +35,7 @@ const ContextMenu = imports.contextMenu;
 const FavoritesPopover = imports.favoritesPopover;
 const Geoclue = imports.geoclue;
 const LayersPopover = imports.layersPopover;
-const LocationServiceNotification = imports.locationServiceNotification;
+const LocationServiceDialog = imports.locationServiceDialog;
 const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
@@ -103,7 +103,8 @@ var MainWindow = GObject.registerClass({
 
         this._mapView = new MapView.MapView({
             mapType: this.application.local_tile_path ?
-                MapView.MapType.LOCAL : MapView.MapType.STREET });
+                MapView.MapType.LOCAL : MapView.MapType.STREET,
+            mainWindow: this });
 
         this._overlay.add(this._mapView);
 
@@ -429,15 +430,6 @@ var MainWindow = GObject.registerClass({
         return false;
     }
 
-    _getLocationServiceNotification() {
-        if (!this._locationServiceNotification) {
-            this._locationServiceNotification =
-                new LocationServiceNotification.LocationServiceNotification();
-        }
-
-        return this._locationServiceNotification;
-    }
-
     _onGotoUserLocationActivate() {
         let message;
 
@@ -450,12 +442,17 @@ var MainWindow = GObject.registerClass({
             switch(Application.geoclue.state) {
             case Geoclue.State.FAILED:
                 message = _("Failed to connect to location service");
-                Application.notificationManager.showMessage(message);
+                Utils.showDialog(message, Gtk.MessageType.ERROR, this);
                 break;
 
             case Geoclue.State.DENIED:
-                let notification = this._getLocationServiceNotification();
-                Application.notificationManager.showNotification(notification);
+                let dialog = new LocationServiceDialog.LocationServiceDialog({
+                    visible: true,
+                    transient_for: this,
+                    modal: true });
+
+                dialog.connect('response', () => dialog.destroy());
+                dialog.show_all();
                 break;
 
             default:
