@@ -88,7 +88,8 @@ var Plan = GObject.registerClass({
         'reset': {},
         'no-more-results': {},
         'itinerary-selected': { param_types: [GObject.TYPE_OBJECT] },
-        'itinerary-deselected': {}
+        'itinerary-deselected': {},
+        'error': { param_types: [GObject.TYPE_STRING] }
     }
 }, class Plan extends GObject.Object {
 
@@ -132,6 +133,10 @@ var Plan = GObject.registerClass({
         this.emit('itinerary-deselected');
     }
 
+    error(msg) {
+        this.emit('error', msg);
+    }
+
     _createBBox() {
         let bbox = new Champlain.BoundingBox();
         this._itineraries.forEach(function(itinerary) {
